import openpyxl
from openpyxl.styles import PatternFill, Font
import datetime
import createFeatures
import helpers

# Constants
now = datetime.datetime.now()
time = datetime.datetime.now().time()
date = str(now.year) + "-" + str(now.month) + "-" + str(now.day) + "-" + str(time.hour) + "-" + str(time.minute)

redFill = PatternFill(start_color='FF0000',
                   end_color='FF0000',
                   fill_type='solid')

yellowFill = PatternFill(start_color='FFFF00',
                   end_color='FFFF0000',
                   fill_type='solid')

greenFill = PatternFill(start_color='00FF00',
                   end_color='00FF00',
                   fill_type='solid')


def createSheet(csv_file):
    """
    createSheet() gets a csv file and creates an excel sheet with the mean of the daily sentiments
    and lists articles if the keyword suicide was found. It also lists if there was any help offered
    in the articles where a suicide was mentioned. For every listed article it calculates the sentiment
    1 and sentiment 2
    :param csv_file: website_download from one day
    :return: excelsheet
    """
    feature_list = createFeatures.createFeatureList(csv_file)
    daily_feature = helpers.getDailySentimentOverview(feature_list)
    keywordArticles = helpers.getArticlesWithSuicide(feature_list)
    keywordFound = not len(keywordArticles) == 0
    color_value = helpers.calcColorValue(daily_feature, keywordFound)
    wb = openpyxl.Workbook()
    sheet = wb.active

    sheet.title = date

    sheet['A1'] = "Suicide Prevention information based on media published on "+date+" File: "+csv_file.title()
    sheet['A1'].font = Font(bold=True)

    sheet['A2'] = "Sentiment with dict"
    sheet['B2'] = daily_feature[0]

    sheet['A3'] = "Sentiment with BayesClassifier"
    sheet['B3'] = daily_feature[1]

    if color_value == 1:
        sheet['D3'].fill = greenFill
    elif color_value == 2:
        sheet['D3'].fill = yellowFill
    elif color_value == 3:
        sheet['D3'].fill = redFill

    if not len(keywordArticles) == 0:
        sheet['A5'] = "At least one article was found that contains the word suicide:"
        sheet['A6'] = "Medium"
        sheet['B6'] = "Title"
        sheet['C6'] = "Link"
        sheet['D6'] = "Sent1"
        sheet['E6'] = "Sent2"
        sheet['F6'] = "Help offered"

        sheet['A6'].font = Font(bold=True)
        sheet['B6'].font = Font(bold=True)
        sheet['C6'].font = Font(bold=True)
        sheet['D6'].font = Font(bold=True)
        sheet['E6'].font = Font(bold=True)
        sheet['F6'].font = Font(bold=True)

        count = len(keywordArticles)
        for a in keywordArticles:
            b = a[2]
            sheet['A'+str(6+count)] = a[3]
            sheet['B'+str(6+count)] = a[4]
            sheet['C'+str(6+count)] = a[5]
            sheet['D'+str(6+count)] = a[0]
            sheet['F'+str(6+count)] = b[1]
            if a[1] == 0:
                sheet['E' + str(6 + count)] = "negative"
            elif a[1] == 100:
                sheet['E' + str(6 + count)] = "positive"

            count -= 1

        wb.save("./Suicide_Prevention_Information_" + date + "_Suicide_mentioned.xlsx")
    else:
        wb.save("./Suicide_Prevention_Information_" + date + ".xlsx")
    return



###################  TEST   ########################
# file = "./testfiles/positive_artikel_glueck.csv"
# createSheet(file)
####################################################

